@@ -17,8 +17,7 @@ use File::Spec;
 sub need_generate {
   my ($opt) = @_;
   
-  my $global_force = $opt->{global_force};
-  my $config_force = $opt->{config_force};
+  my $force = $opt->{force};
   my $input_files = $opt->{input_files};
   my $output_file = $opt->{output_file};
   
@@ -34,7 +33,7 @@ sub need_generate {
     for my $spvm_builder_module_file_name (@$spvm_builder_module_file_names) {
       my $module_file = "$builder_loaded_dir/$spvm_builder_module_file_name";
       unless (-f $module_file) {
-        confess 'Unexpected';
+        confess "Can't find $module_file";
       }
       push @spvm_core_files, $module_file;
     }
@@ -44,7 +43,7 @@ sub need_generate {
     for my $spvm_core_header_file_name (@$spvm_core_header_file_names) {
       my $spvm_core_header_file = "$builder_loaded_dir/SPVM/Builder/include/$spvm_core_header_file_name";
       unless (-f $spvm_core_header_file) {
-        confess 'Unexpected';
+        confess "Can't find $spvm_core_header_file";
       }
       push @spvm_core_files, $spvm_core_header_file;
     }
@@ -54,7 +53,7 @@ sub need_generate {
     for my $spvm_core_source_file_name (@$spvm_core_source_file_names) {
       my $spvm_core_source_file = "$builder_loaded_dir/SPVM/Builder/src/$spvm_core_source_file_name";
       unless (-f $spvm_core_source_file) {
-        confess 'Unexpected';
+        confess "Can't find $spvm_core_source_file";
       }
       push @spvm_core_files, $spvm_core_source_file;
     }
@@ -69,10 +68,7 @@ sub need_generate {
   }
 
   my $need_generate;
-  if ($global_force) {
-    $need_generate = 1;
-  }
-  elsif ($config_force) {
+  if ($force) {
     $need_generate = 1;
   }
   else {
@@ -357,10 +353,23 @@ sub get_spvm_builder_module_file_names {
 
 sub get_spvm_core_source_file_names {
   
+  my $spvm_core_compiler_only_source_file_names = &get_spvm_core_compiler_only_source_file_names();
+  my $spvm_core_common_source_file_names = &get_spvm_core_common_source_file_names();
+  
+  my @spvm_core_source_file_names = (
+    @$spvm_core_compiler_only_source_file_names,
+    @$spvm_core_common_source_file_names
+  );
+  
+  return \@spvm_core_source_file_names;
+}
+
+sub get_spvm_core_compiler_only_source_file_names {
+  
   my @spvm_core_source_file_names = qw(
-    spvm_allocator.c
     spvm_allow.c
-    spvm_api.c
+    spvm_api_compiler.c
+    spvm_api_precompile.c
     spvm_array_field_access.c
     spvm_basic_type.c
     spvm_block.c
@@ -369,32 +378,26 @@ sub get_spvm_core_source_file_names {
     spvm_class.c
     spvm_class_var_access.c
     spvm_class_var.c
-    spvm_implement.c
     spvm_compiler.c
     spvm_constant.c
-    spvm_csource_builder_precompile.c
     spvm_descriptor.c
     spvm_dumper.c
     spvm_field_access.c
     spvm_field.c
-    spvm_hash.c
-    spvm_list.c
+    spvm_interface.c
     spvm_method.c
-    spvm_my.c
     spvm_op.c
     spvm_op_checker.c
     spvm_opcode_array.c
     spvm_opcode_builder.c
-    spvm_opcode.c
-    spvm_public_api.c
-    spvm_runtime.c
-    spvm_string.c
-    spvm_string_buffer.c
+    spvm_precompile.c
+    spvm_constant_string.c
     spvm_switch_info.c
     spvm_toke.c
     spvm_type.c
     spvm_use.c
     spvm_var.c
+    spvm_var_decl.c
     spvm_yacc.c
     spvm_yacc_util.c
   );
@@ -402,13 +405,36 @@ sub get_spvm_core_source_file_names {
   return \@spvm_core_source_file_names;
 }
 
+sub get_spvm_core_common_source_file_names {
+  
+  my @spvm_core_source_file_names = qw(
+    spvm_allocator.c
+    spvm_api_allocator.c
+    spvm_api.c
+    spvm_api_runtime.c
+    spvm_api_string_buffer.c
+    spvm_hash.c
+    spvm_list.c
+    spvm_native.c
+    spvm_opcode.c
+    spvm_runtime.c
+    spvm_string_buffer.c
+  );
+  
+  return \@spvm_core_source_file_names;
+}
 
 sub get_spvm_core_header_file_names {
   
   my @spvm_core_header_file_names = qw(
     spvm_allocator.h
     spvm_allow.h
+    spvm_api_allocator.h
+    spvm_api_compiler.h
     spvm_api.h
+    spvm_api_precompile.h
+    spvm_api_runtime.h
+    spvm_api_string_buffer.h
     spvm_array_field_access.h
     spvm_basic_type.h
     spvm_block.h
@@ -420,18 +446,14 @@ sub get_spvm_core_header_file_names {
     spvm_class_var.h
     spvm_compiler.h
     spvm_constant.h
-    spvm_csource_builder_precompile.h
     spvm_descriptor.h
     spvm_dumper.h
     spvm_field_access.h
     spvm_field.h
     spvm_hash.h
-    spvm_implement.h
-    spvm_limit.h
+    spvm_interface.h
     spvm_list.h
     spvm_method.h
-    spvm_my.h
-    spvm_name_info.h
     spvm_native.h
     spvm_object.h
     spvm_op_checker.h
@@ -439,23 +461,24 @@ sub get_spvm_core_header_file_names {
     spvm_opcode_builder.h
     spvm_opcode.h
     spvm_op.h
+    spvm_precompile.h
     spvm_public_api.h
     spvm_runtime_basic_type.h
     spvm_runtime_class.h
     spvm_runtime_class_var.h
     spvm_runtime_field.h
     spvm_runtime.h
-    spvm_runtime_manager.h
     spvm_runtime_method.h
-    spvm_runtime_string.h
+    spvm_runtime_constant_string.h
     spvm_runtime_type.h
-    spvm_string.h
     spvm_string_buffer.h
+    spvm_constant_string.h
     spvm_switch_info.h
     spvm_toke.h
     spvm_typedecl.h
     spvm_type.h
     spvm_use.h
+    spvm_var_decl.h
     spvm_var.h
     spvm_weaken_backref.h
     spvm_yacc.h
